\name{isop.calc2set}
\alias{isop.calc2set}
\title{ ISOP model for two sets of items }
\description{
  The function calculates nonparametric indices for testing the validity of an ISOP-Model, suggested by Scheiblechner, for two given sets of items. Having one item in criterion and rest of the items in predictor set can be used for item selection. Having many predictors and many criterions corresponds to canonical correlation.
}
\usage{
isop.calc2set(raw, set1, set2, verbose = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{raw}{ The data, ISOP should be applied on }
  \item{set1}{ Indices of items in criterion set }
  \item{set2}{ Indices of items in predictor set }
  \item{verbose}{ Print information about progress }
}
\value{
  \item{ns, nd, nt, nss, ndd, nsd}{Frequencies of concordant, discordant and tied vectors}
  \item{ps, pd, pt, pss, pdd, psd}{Probabilities of concordant, discordant and tied vectors}
  \item{predictability}{ Multivariate index of ordinal association. Varies between -1 and +1. Does not include ties.}
  \item{stddev}{Standard devation of predictability}
  \item{isotonicity}{Nonparametric measure of positive diagonalization of an ordered contingency table. Varies between 0 and +1. Includes ties.}
  \item{compatibility}{Number of pairs concordant or tied}
  \item{n}{Number of response vectors}
  \item{z}{z-value of predictability}
  \item{stderr}{Standard error of predictability}
  \item{ubas}{Upper bound of asymptotic }
}
\references{ 
Hartmann Scheiblechner (2003) 
Nonparametric IRT: Testing the bi-isotonicity of isotonic probabilistic models (ISOP) 
\emph{Psychometrika}, \bold{68}, 1, 79--96
}
\author{ Stefan Nachtnebel }

\seealso{ \code{\link{isop.calc1set}}}

\keyword{ nonparametric }
\keyword{ multivariate }
